#
# spec file for package wxMaxima
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tarname wxmaxima
Name:           wxMaxima
Version:        16.04.2
Release:        3.2
Summary:        Graphical User Interface for the maxima Computer Algebra System
License:        GPL-2.0+
Group:          Productivity/Scientific/Math
Url:            http://wxmaxima.sourceforge.net/
Source0:        http://download.sourceforge.net/wxmaxima/%{tarname}-%{version}.tar.gz
Source1:        wxMaxima.desktop
Source2:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM wxMaxima-appstream-xml-filename.patch badshah400@gmail.com -- Fix the appstream xml file name (must be identical to .desktop file name w/o ext) and the reference to the .desktop file therein (refers to wxmaxima.desktop while installing wxMaxima.desktop); reported upstream
Patch0:         wxMaxima-appstream-xml-filename.patch
# REQUIRED FOR PATCH0
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  inkscape
BuildRequires:  maxima >= 5.30.0
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel >= 3
# gnuplot is needed for plotting
Requires:       gnuplot
# libgnomeprint is needed for printing
Requires:       libgnomeprint
Requires:       maxima >= 5.30.0
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    ppc64 ppc64le

%description
wxMaxima is a cross platform GUI for the computer algebra system maxima
based on wxWidgets.

wxMaxima features include:

    * 2D formatted math display: wxMaxima implements its own math display
      engine to nicely display maxima output.
    * Menu system: most maxima commands are available through menus. Most
      used functions are also available through a button panel at below
      the input line.
    * Dialogs: commands which require more that one argument can be entered
      through dialogs so that there is no need to remember the exact syntax.
    * Command line history: the input line has command history and command
      completion based on previous input.
    * Create documents: text can be mixed with math calculations to create
      documents. See the howto for tips on how to use these features.
      Documents can be saved and edited again later.

%prep
%setup -q -n %{tarname}-%{version}
%patch0 -p1

%build
autoreconf -fvi
%configure \
           --enable-printing \
           --enable-unicode-glyphs \
           --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
# REMOVE UPSTREAM INSTALLED DESKTOP FILE BECAUSE IT IS INCOMPLETE...
rm %{buildroot}%{_datadir}/applications/wxMaxima.desktop
# ...THEN INSTALL OURS
install -D -m 644 %{SOURCE1} %{buildroot}%{_datadir}/applications/wxMaxima.desktop

# INSTALL HI-RES ICONS GENERATED OUT OF UPSTREAM SVG ICON
for i in 24 32 48 64 128 256 512
do
  inkscape -w ${i} data/wxmaxima.svg -e wxmaxima-${i}.png
  install -D -m 0644 wxmaxima-${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/wxmaxima.png
done
install -D -m 0644 data/wxmaxima.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/wxmaxima.svg

# REMOVE UNNECESSARY ICONS OUT OF PIXMAPS
rm %{buildroot}%{_datadir}/pixmaps/wxmaxima*

%suse_update_desktop_file wxMaxima

%fdupes %{buildroot}%{_prefix}

%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post
%install_info --info-dir=%{_infodir} %{_infodir}/wxmaxima.info%{ext_info}

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/wxmaxima.info%{ext_info}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING README.md ChangeLog
%{_bindir}/*
%{_datadir}/wxMaxima/
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%{_datadir}/icons/hicolor/*/apps/wxmaxima.*
%{_datadir}/applications/wxMaxima.desktop
%if 0%{?suse_version} == 1315
%dir %{_datadir}/appdata
%endif
%{_datadir}/bash-completion/completions/wxmaxima
%{_datadir}/appdata/wxMaxima.appdata.xml
%{_mandir}/man1/wxmaxima*%{ext_man}
%{_infodir}/wxmaxima.info%{ext_info}
%{_datadir}/mime/packages/*.xml
%{_datadir}/pixmaps/*.svg

%changelog
* Tue Aug  9 2016 tchvatal@suse.com
- Version update to 16.04.2:
  * various small bugfixes
- Sort with spec-cleaner
* Fri Jul 15 2016 badshah400@gmail.com
- Add wxMaxima-appstream-xml-filename.patch: Fix the appstream xml
  file name (must be identical to .desktop file name w/o ext) and
  the reference to the .desktop file therein (refers to
  wxmaxima.desktop while installing wxMaxima.desktop); reported
  upstream.
- Update file list accordingly:
  wxmaxima.appdata.xml -> wxMaxima.appdata.xml
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 16.04.1:
  + Bug fixes.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 16.04.0:
  + A TeX-like subscript notation: A_1 is now by default shown as
    an A with an 1 as subscript
  + High-quality icons for high-dpi screens.
  + Some broken .wxmx files generated with wxMaxima 13.04 and
    older will now automatically be repaired
  + Tried to make communication with maxima more stable
  + Debug: A monitor for the xml communication between maxima and
    wxMaxima
  + Leading White-space in front of a character that has to be
    escaped in XML is no more ignored.
  + jpeg-encoded images are now no more converted to much larger
    png files on saving .wxmx files and on exporting.
  + Images will now actually be converted to the target format.
  + Bumped the minor version of the .wxmx format: Some old
    versions of wxmaxima will replace .jpg files embedded in .wxmx
    files by a placeholder on load
  + Increased both speed and memory-efficiency of image handling
  + Save the zoom factor at exit and reload it on opening a new file
  + An option that makes wxMaxima use user-defined labels instead
    of %%o where an user-defined label exists. Works well together
    with unchecking the "export code cells" config item.
  + A separate text style for user-defined labels.
  + The "evaluate all cells" and "evaluate till here" now start
    with a fresh instance of maxima
  + TeX export now should work with most unicode chars we have ESC
    sequences for.
  + An auto-repair functionality that repairs most .wxmx files
    wxMaxima 13.04 was not able to open again.
  + A few new ESC sequences and markdown commands.
  + "#" now is shown as a "not equal" sign as a "not equal" sign
    already would be interpreted as "#".
  + Teach CCL on Windows how to deal with unicode variable names
    like ü and α. For SBCL the necessary change has been done on
    the maxima side.
  + Sidebars for symbols
  + Printing text cells now works again
  + The <ESC> key now works as a shortcut that closes the search
    dialogue.
  + A copy-to-MathML feature
  + Many bug, usability and performance fixes
  + Most importantly: If it is a cursor it now blinks.
- No longer rm .menu file, not bundled in upstream tarball any
  more.
* Mon Mar 28 2016 dvaleev@suse.com
- ExcludeArch POWER64 architecture, maxima is excluded due to missing
  clisp
* Tue Sep  8 2015 badshah400@gmail.com
- Update to version 15.08.2:
  - Bugs fixed:
    + Added en.po to distribution.
    + Disable check for event types.
    + Correctly update the stats sidebar visibility in menus.
    + Update version number.
    + Don't remove new lines from lisp cells.
    + Added en.mo to distrubution.
- Remove wxMaxima-missing-make-targets.patch: incorporated
  upstream.
* Thu Sep  3 2015 badshah400@gmail.com
- Update to version 15.08.1:
  + Bug fixes (undocumented).
- Rebase wxMaxima-missing-make-targets.patch; two issues fixed
  upstream (and removed from patch), one issue persists.
* Wed Aug 19 2015 badshah400@gmail.com
- Update to version 15.08.0:
  + MathJAX now provides scaleable equations and extended
    drag-and-drop for the html export.
  + The table-of-contents-sidebar now shows the current cursor
    position.
  + Fixed a few instances of cursors jumping out of the screen.
  + Fixed a few instances of cursors jumping to the beginning or
    end of the worksheet.
  + Better detection which cell maxima is processing and if it
    still is doing so.
  + Regression: Hiding the toolbar didn't work on some systems.
  + Markdown support for <=, >=, <=>, <-, ->, <->, => and +/-
    symbols.
  + An option to not export maxima's input as well as the output.
  + An option to use High-resolution bitmaps for the HTML export.
  + Images that are too big for the window now are displayed in a
    scaled-down version.
  + Fixed the support for out-of-tree-bulds that was broken in 15.04.
  + Meaningful ALT texts for the HTML export to provide accessibility.
  + An option to include the .wxmx file in the .html export.
  + Performance fixes that are espectionally effective for MSW
  + Unification of some platform-specific code.
  * bash autocompletion.
  + A fourth sectioning level.
  + Made entering uppercase greek letters easier and documented
    how to input special unicode symbols.
  + Syntax highlighting in code cells.
  + Automatic highlighting of text equal to the currrently
    selected one.
  + A batch mode that pauses evaluation if maxima asks a question.
  + A "halt on error" feature.
  + Now evaluation of a new command is only triggered if
    evaluation of the last command has finished. This means that
    output from maxima is always appended to the right cell.
  + Un-broke error and question handling for multiple commands per
    cell. Sincewe now send maxima's input command-per-command this
    means a cell with multiple commands is no more evaluated
    faster than multiple cells with single commands each.
  + If ever a end-of-evaluation marker gets lost there is a new
    "trigger evaluation" menu entry in the maxima menu.
  + On wxGtk autocompletion was replaced by a content assistant
    that is based on the surprisingly powerful autocompletion
    feature.
  + Ctrl+Tab now launches the autocompletion (or content
    assistant, if available).
  + Tab and Shift+Tab now indent and unindent regions.
  + Ctrl+Mouse wheel and Ctrl++/- now zoom in and out of the
    worksheet.
  + Allow Extending selection from part of a single cell to
    multiple cells.
  + An Autoindent functionality.
- Changes from version 15.04.0:
  + See /usr/doc/packages/wxMaxima/ChangeLog file.
- Explicit dependency on wxwidgets >= 3.0.
- Update maxima version required for building.
- Package ChangeLog file available in upstream tarball since
  version 15.04.0.
- Add patch required because upstream missed a few files from
  the tarball:
  + wxMaxima-missing-make-targets.patch (touches autotool files
    BR on autoreconf required).
- Generate and install hicolor icons from the bundled svg icon
  file; introduces BR on inkscape, hicolor-icon-theme.
- Use %%post and %%postun scriptlets as necessary.
- Update filelist to include new files installed by upstream, as
  well as hicolor icons.
- Update desktop menu filename to be consistent with upstream; add
  Mimetypes specification to .desktop file.
* Mon Feb  9 2015 jengelh@inai.de
- Use wxWidgets 3 and remove manual dependencies.
  Run fdupes over more files.
* Thu Dec 25 2014 badshah400@gmail.com
- Update to version 14.12.1:
  + No documentation of changes.
- Changes from version 14.12.0:
  + No documentation of changes.
* Wed Sep 17 2014 badshah400@gmail.com
- Update to verson 14.09.0:
  + No detailed changelog available
- Packaging changes:
  + Adapt to source tarball name change from wxMaxima to wxmaxima
  + Add rpmlintrc file as source.
* Sat May 25 2013 badshah400@gmail.com
- Update to version 13.04.2:
  + Fix a bug with matchParens=false option
- Changes from version 13.04.1:
  + Include all files in the source tgz
- Drop wxMaxima-fix-missing-locale.patch; upstream now includes
  all required source files, making patch unnecessary.
* Tue Apr 23 2013 badshah400@gmail.com
- Update to version 13.04.0:
  + No detailed changelog available
- Add wxMaxima-fix-missing-locale.patch to fix build failure while
  trying to install a locale that is missing from the tarball.
* Tue Sep 11 2012 badshah400@gmail.com
- Update to version 12.09.0:
  + No detailed changelog available
- Change source url in spec file.
* Sat May 19 2012 badshah400@gmail.com
- Update to version 12.04:
  + No detailed changelog available.
- Spec file cleanups:
  + Correct License tag in keeping with spdx.org recommendations
  + Use fdupes to link duplicate files
* Sun Sep 18 2011 lars@linux-schulserver.de
- update to 11.08.0
* Thu Mar 17 2011 sbrabec@suse.cz
- Compile with wxcontainer variant, binary linked with STL crashes.
  https://sourceforge.net/projects/wxmaxima/forums/forum/435775/topic/4410333
* Mon Mar  7 2011 sbrabec@suse.cz
- Compile with openSUSE wxWidgets (default variant).
- Remove BuildRequires: libstdc++ that is no more provided.
* Sun Mar  6 2011 lars@linux-schulserver.de
- update to 0.8.7
* Sun Sep 19 2010 werner.ho@gmx.de
- updated to version 8.6
* Sun Nov 22 2009 lars@linux-schulserver.de
- removed "--disable-statix-wx" as it looks like this triggers an
  error "Maxima process terminated" in the status bar, even though
  Maxima runs fine either by itself or through xMaxima.
  (Thanks to Moby for reporting the issue!)
* Mon Sep 21 2009 lars@linux-schulserver.de
- update to 0.8.3a
* Sat Apr 25 2009 lars@linux-schulserver.de
- update to 0.8.2:
  + new wxMaxima document format (not compatible with .wxm) which
    saves maxima output and inline plots into a single file (you
    can still save and load ".wxm" format, but you don't get the
    improvements of the new one)
  + images can be inserted into the document
  + when input is modified after evaluation, output becomes gray to
    indicate it is no longer up to date
  + styles section improved: colors can be set for all elements of
    wxmaxima document, title, section and text cells can have a
    different font, support for loading/saving styles into a file
  + "Open Recent" added to the file menu
  + "unix copy" (copy on select) now working as expected
    (selection copies, middle mouse click pastes) option to use
    evaluate with enter instead of shift-enter
  + full screen mode (alt + enter)
  + backspace and delete keys can be used for deleting cells when
    horizontal cursor is active
  + Bugfix: Restart Maxima doesn't clear the document
  + Bugfix: reduced the number of redraws - the GUI feels a bit snappier
  + Bugfix: Opening a WXM file doesn't automaticly restart Maxima
- removed obsolete --enable-dnd
- cleanup specfile
* Fri Dec 19 2008 lars@linux-schulserver.de
- update to 0.8.1:
  + bugfix: set horizontal cursor after Maxima header when starting
    wxMaxima
  + bugfix: when horizontal cursor is active keys like left, right,
    page up/down, home/end don't insert a new input cell
  + new feature: optional, display center dot instead of *
* Fri Dec  5 2008 lars@linux-schulserver.de
- update to 0.8.0:
  + wxMaxima document now made of 'cells'
  + cells can be evaluated with SHIFT-ENTER
  + long Maxima outputs can be hidden by clicking into the triangle
    at the top of that cell's left bracket
  + reorganised some menus
  + cells can now be edited by single-click
  + if you have a selection of text/code, ([{ will put ([{}]) around
    selection and place cursor before first ([{, pressing }]) will put
    the cursor after the last }])
  + double clicking will select the word under the cursor
  + double clicking on (,[,{ or },],) will select the text/code between ([{ }])
  + F1 now selects the word under cursor if there's no selection, and
    searches help for that word
  + removed the INPUT line
  + introduced a 'horizontal cursor': click between cells to set it,
    start typing to insert a new input cell, press F6 to insert a new
    text cell, SHIT-UP/DOWN or click'n'drag selects cells
  + Maxima questions answered in the document - a cursor should appear,
    SHIFT-ENTER sends your answer to Maxima. If a cursor doesn't appear,
    click below the cell, type the answer and press SHIFT-ENTER
* Wed Oct  8 2008 lars@linux-schulserver.de
- own %%_datadir/wxMaxima
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Fri Aug 22 2008 lars@linux-schulserver.de
- update to 0.7.6
- build also on fedora
* Sun May 25 2008 lars@linux-schulserver.de
- disable gnuplot patch for now (os-edu #0000039)
* Mon Apr 21 2008 lars@linux-schulserver.de
- update to 0.7.5:
  + part of wxMaxima-ATTRIBUTE_PRINTF.patch is upstream:
  - > wxMaxima-0.7.5-ATTRIBUTE_PRINTF.patch
  + don't try to use outdated gnuplot:
  wxMaxima-0.7.5-old_gnuplot.patch
- updated desktop file (added german description)
* Sun Feb  3 2008 kirill.kirillov@gmail.com
- fix gnuplot requires
* Mon Dec 10 2007 lars@linux-schulserver.de
- update to version 0.7.4
- combine the patches wxMaxima-MathParser.cpp.diff and
  wxMaxima-MathParser.h.diff in wxMaxima-ATTRIBUTE_PRINTF.patch
- enable unicode-glyphs
- enable printing
- Enable drag'n'drop support
* Fri Sep  7 2007 Werner Hoch <werner.ho@gmx.de>
- updated to version 0.7.3
* Thu May 17 2007 Werner Hoch <werner.ho@gmx.de>
- updated to version 0.7.2
* Fri Feb  2 2007 Werner Hoch <werner.ho@gmx.de>
- updated to version 0.7.1
- added ATTRIBUTE_PRINTF patches
* Sun Aug 13 2006 Leon Freitag <leon@links2linux.de>
- initial release for BS
- minor corrections to make the prefix relocatable
- update the group to be compatible with the SPC
* Tue Dec 14 2004 Andrej Vodopivec <andrejv@users.sourceforge.net>
- Added french translation files.
* Tue Aug 24 2004 Andrej Vodopivec <andrejv@users.sourceforge.net>
- Initial spec file.
